
%Please run this code cell by cell reading the comments to see
%a demonstration of the HCNS survival estimation package:


%% 1st cell (Simulated example of the paper)
close all % close all figures
clear all % clear all variables
clc       % clean the command window

n=300
x=wblrnd(2,3,n,1); % Generate some data from the Weib(2,3)
c=wblrnd(2,3,n,1); % Generate also from the Weib(2,3) the censoring variable
xcen=min(x,c);     % Derive the censored data (expected censoring=50%)
status=(x>c);      % Derive the censoring indicator
% The data for analysis are the variables xcen and status

% The presented approach is carried out from the following line:
[bhat Hx Fx Sx KMdist knots]=HCNS(xcen, status,0, [], 'auto', 2,[], 'survivor')

%if you want to calculate the estimate at time 2 and 2.5 for the survival
%the simply type:
Sx([2 2.5])

%Similarly for the cumulative distribution:
Fx([2 2.5])

%or the cumulative hazard:
Hx([2 2.5])


%% 2nd cell: Generate some data with a covariate and then use the HCNS to estimate:

close all %close all figures
clear all %clear all variables
clc       %clean the Command Window

n=300;
u=rand(n,1);  % Generate n number from the Uniform(0,1)
a=2;b=3;g=2;  %Set the values of the baseline survival, and cox coef g=2
z=exprnd(0.3,n,1); %Generate the covariate to be exponential distributed with mean 3
x=(-log(u)./(a^(-b).*exp(g.*z))).^(1./b); %Generate values from Cox model
c=exprnd(4,n,1); % Generate the censoring variable
status=(x>c);    % Derive the censoring indicator
xcen=min(x,c);   % Derive censored time values

level_of_censoring=mean(status)


%The data for analysis are the variables: time, status, z (the covariate)
[bhat Hx Fx Sx KMdist knots gcoxhat stats]=HCNS(xcen, status, 0, [z], 'auto',2,[], 'survivor')



%% 3rd cell: 
%Ask for the CDF plot of the baseline distribution (that is for Z=0), and provide estimates for Z=0.2 along
%with the corresponding survival plot.
close all %close all figures
[bhat Hx Fx Sx KMdist knots gcoxhat stats]=HCNS(xcen, status, 0, z, 'auto', 2,[], 'cdf', [0.2],'survivor')

%Calculate the survival, cdf and cumulative hazard estimate (for Z=0.2) at time points [0.5 1 1.5]:

Sx([0.5 1 1.5])
Fx([0.5 1 1.5])
Hx([0.5 1 1.5])


%% 4th cell: 
%Ask for the CDF plot of the baseline distribution (Z=0), and provide estimates for Z=0.2 along
%with the corresponding survival plot.
%Also provide some options regarding the built in coxphfit MATLAB function:


close all %close all figures
toler=10^(-7);
iter=1000;
options = statset('Display','final','TolX',toler,'TolFun',toler, 'TolBnd',toler, 'MaxIter', iter, 'MaxFunEvals', iter)
[bhat Hx Fx Sx KMdist knots gcoxhat]=HCNS(xcen, status, 0, z, 'auto', 2,options, 'cdf', [0.2],'survivor')

%Calculate the survival, cdf and cumulative hazard estimate (for Z=0.2) at time points [0.5 1 1.5]:

Sx([0.5 1 1.5])
Fx([0.5 1 1.5])
Hx([0.5 1 1.5])


%% 5th cell: 
%Ask for the CDF plot of the baseline distribution (Z=0), and provide estimates for Z=0.2 along
%with the corresponding survival plot.
%Also provide some options regarding the built in coxphfit MATLAB function:


close all %close all figures
toler=10^(-7);
iter=1000;
options = statset('Display','final','TolX',toler,'TolFun',toler, 'TolBnd',toler, 'MaxIter', iter, 'MaxFunEvals', iter)
[bhat Hx Fx Sx KMdist knots gcoxhat stats]=HCNS(xcen, status, 0, z, 'auto', 2,options, 'cdf', [0.2],'survivor')

%Calculate the survival, cdf and cumulative hazard estimate (for Z=0.2) at time points [0.5 1 1.5]:

Sx([0.5 1 1.5])
Fx([0.5 1 1.5])
Hx([0.5 1 1.5])



%% 6th cell: 
%Derive confidence intervals for the cumulative hazard (CIH) for the
%survival (CIS) and the cumulative distribution (CIF) via the bootstrap
%Ask for 300 bootstrap samples.
%Derive CI's at time values [1 1.5 2] for the profile "mean(z)".

%The count will inform you how many bootstrap samples needed to be
%discarded (to gather 300 bootstrap samples) based on the criterion
%discard=10. Since 'discard' is set equal to 10, any bootstrap sample that will provide
%a cox coef outside the interval gcox+-10*std(gcox) will be discarded.
%This is done because for some bootstrap iterations all data might turn out
%to be censored (or all data for a specific covariate value). The cox coef
%might tend to infinity. Also problems when the last event of one category
%is earlier than the first event of the other during fitting a Cox model
%may occur. By using the discard option you can discard these "unwanted"
%bootstrap samples. However, caution is needed so as not to cause significant
%bias. 


%the knots are supplied by the user:
knots=[ 0.3342    0.6269    1.7976    2.0902    2.6756    2.9682]
[CIH CIS CIF count]=HCNSboots(xcen, status, 0, z, knots, 2, [], [1 1.5 2], 300, 0.05, 10, [mean(z)])


%% 8th cell: 
%The same thing with the knots set to 'auto'.
%This might take several minutes depending on your computer.
%The progress will be reported in the Command Window:

[CIH CIS CIF count]=HCNSboots(xcen, status, 0, z, 'auto', 2, [], [1 1.5 2], 300, 0.05, 10, [mean(z)])




